==> haskell-cmark-gfm-0.2.2-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cmark-gfm.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cmark-gfm
version:              0.2.2
visibility:           public
id:                   cmark-gfm-0.2.2-IsWGGimFOs38exGDgCINqh
key:                  cmark-gfm-0.2.2-IsWGGimFOs38exGDgCINqh
license:              BSD-3-Clause
copyright:            (C) 2015--17 John MacFarlane, (C) 2017--19 Ashe Connor
maintainer:           ashe@kivikakk.ee
author:               Ashe Connor
homepage:             https://github.com/kivikakk/cmark-gfm-hs
synopsis:             Fast, accurate GitHub Flavored Markdown parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/github/cmark-gfm libcmark-gfm>, the reference
    parser for <https://github.github.com/gfm/ GitHub Flavored Markdown>, a fully
    specified variant of Markdown. It includes sources for
    libcmark-gfm (0.29.0.gfm.0) and does not require prior installation of the
    C library.

category:             Text
abi:                  8ced79d7bf2eca118e6ad512cbf6dd24
exposed:              True
exposed-modules:      CMarkGFM
import-dirs:          /usr/lib/ghc-8.10.2/site-local/cmark-gfm-0.2.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/cmark-gfm-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/cmark-gfm-0.2.2
hs-libraries:         HScmark-gfm-0.2.2-IsWGGimFOs38exGDgCINqh
extra-libraries:      cmark-gfm cmark-gfm-extensions
depends:              base-4.14.1.0 bytestring-0.10.10.0 text-1.2.3.2
haddock-interfaces:   /usr/share/doc/haskell-cmark-gfm/html/cmark-gfm.haddock
haddock-html:         /usr/share/doc/haskell-cmark-gfm/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmark-gfm-0.2.2-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cmark-gfm.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cmark-gfm
version:              0.2.2
visibility:           public
id:                   cmark-gfm-0.2.2-8jJkHpyvfRlEr2rpEqxfuN
key:                  cmark-gfm-0.2.2-8jJkHpyvfRlEr2rpEqxfuN
license:              BSD-3-Clause
copyright:            (C) 2015--17 John MacFarlane, (C) 2017--19 Ashe Connor
maintainer:           ashe@kivikakk.ee
author:               Ashe Connor
homepage:             https://github.com/kivikakk/cmark-gfm-hs
synopsis:             Fast, accurate GitHub Flavored Markdown parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/github/cmark-gfm libcmark-gfm>, the reference
    parser for <https://github.github.com/gfm/ GitHub Flavored Markdown>, a fully
    specified variant of Markdown. It includes sources for
    libcmark-gfm (0.29.0.gfm.0) and does not require prior installation of the
    C library.

category:             Text
abi:                  cc3072d4df349e813e31b84dc3cddd46
exposed:              True
exposed-modules:      CMarkGFM
import-dirs:          /usr/lib/ghc-8.10.2/site-local/cmark-gfm-0.2.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/cmark-gfm-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/cmark-gfm-0.2.2
hs-libraries:         HScmark-gfm-0.2.2-8jJkHpyvfRlEr2rpEqxfuN
extra-libraries:      cmark-gfm cmark-gfm-extensions
depends:              base-4.14.1.0 bytestring-0.10.10.0 text-1.2.3.2
haddock-interfaces:   /usr/share/doc/haskell-cmark-gfm/html/cmark-gfm.haddock
haddock-html:         /usr/share/doc/haskell-cmark-gfm/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
